==> dde-daemon_5.13.12.orig.tar.xz: dde-daemon-5.13.12/misc/ts/com.deepin.daemon.Fprintd.policy/policy_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.fprintd.enroll!message" line="0"/>
			<source>Authentication is required to add fingerprint password</source>
			<translation>Do dodania hasła linii papilarnych wymagane jest uwierzytelnienie</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.enroll!description" line="0"/>
			<source>Add fingerprint password</source>
			<translation>Dodaj hasło linii papilarnych</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.delete-enrolled-fingers!message" line="0"/>
			<source>Authentication is required to clear fingerprint passwords</source>
			<translation>Do wyczyszczenia haseł odcisków palców wymagane jest uwierzytelnienie</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.delete-enrolled-fingers!description" line="0"/>
			<source>Clear fingerprint passwords</source>
			<translation>Wyczyść hasła odcisków palców</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!message" line="0"/>
			<source>Authentication is required to rename fingerprint password</source>
			<translation>Uwierzytelnienie jest wymagane do zmiany nazwy hasła linii papilarnych</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!description" line="0"/>
			<source>Rename fingerprint password</source>
			<translation>Zmień nazwę hasła linii papilarnych</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.manager!message" line="0"/>
			<source>Password is required to perform this action</source>
			<translation>Do wykonania tej czynności wymagane jest hasło</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.manager!description" line="0"/>
			<source>Manage fingerprint passwords</source>
			<translation>Zarządzaj hasłami odcisków palców</translation>
		</message>
	</context>
</TS>

==> dde-daemon_5.14.18.orig.tar.xz: dde-daemon-5.14.18/misc/ts/com.deepin.daemon.Fprintd.policy/policy_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.fprintd.enroll!message" line="0"/>
			<source>Authentication is required to add fingerprint password</source>
			<translation>Uwierzytelnienie jest wymagane do dodania hasła linii papilarnych</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.enroll!description" line="0"/>
			<source>Add fingerprint password</source>
			<translation>Dodaj hasło linii papilarnych</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.delete-enrolled-fingers!message" line="0"/>
			<source>Authentication is required to clear fingerprint passwords</source>
			<translation>Uwierzytelnienie jest wymagane do wyczyszczenia haseł odcisków palców</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.delete-enrolled-fingers!description" line="0"/>
			<source>Clear fingerprint passwords</source>
			<translation>Wyczyść hasła odcisków palców</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!message" line="0"/>
			<source>Authentication is required to rename fingerprint password</source>
			<translation>Uwierzytelnienie jest wymagane do zmiany nazwy hasła linii papilarnych</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!description" line="0"/>
			<source>Rename fingerprint password</source>
			<translation>Zmień nazwę hasła linii papilarnych</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.manager!message" line="0"/>
			<source>Password is required to perform this action</source>
			<translation>Do wykonania tej czynności wymagane jest hasło</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.manager!description" line="0"/>
			<source>Manage fingerprint passwords</source>
			<translation>Zarządzaj hasłami odcisków palców</translation>
		</message>
	</context>
</TS>
